==> glog-1.00.tar.gz: glog-1.00/funcs.php <==
<?php
# Library functions
#
# $Id: funcs.php,v 1.3.2.2 2004/04/15 09:43:09 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (PROGRAM != 1)
		exit;

	include("config.php");

	function get_filename($fname) {
		return DAY_DIR . $fname . ".txt";
	}

	/* !!! Global !!! Needs further optimizations !!! */
	$days = load_days();
	$months = array();
	foreach ($days as $tmp => $tmpdate) {
		$tmpdate = ereg_replace("-[0-9]+$","",$tmpdate);
		if (!isset($months[$tmpdate])) {
			$months[$tmpdate] = $tmpdate;
		}
	}
	asort($months);
	$months_bg = array(
		1	=>	"",
		2	=>	"",
		3	=>	"",
		4	=>	"",
		5	=>	"",
		6	=>	"",
		7	=>	"",
		8	=>	"",
		9	=>	"",
		10	=>	"",
		11	=>	"",
		12	=>	""
	);

	/*      $length */
	function gen_uniq($rnd=0,$length=12) {
		srand((double)microtime()*10000000+$rnd);
		$Pool = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz01234567890';
		$sid = '';
		for($index = 0; $index < $length; $index++) {
			$sid .= substr($Pool, (rand()%(strlen($Pool))), 1);
		}
		return($sid);
	}

	function load_days() {
		$files = array();
		if (is_dir(DAY_DIR) && is_readable(DAY_DIR)) {
			if ($dh = opendir(DAY_DIR)) {
				while (($file = readdir($dh)) !== false) {
					if (filetype(DAY_DIR . $file) == "file" &&
					    ereg("[0-9]{4}-[0-9]{2}-[0-9]{2}\.txt$", $file))
					{
						$file = ereg_replace(".txt$","",$file);
						$files[$file] = $file;
					}
				}
				closedir($dh);
			}
		} else {
			print "Can't open \"" . DAY_DIR . "\" directory.<br />Make sure the directory exists and has correct permissions!<br /><br />";
		}
		arsort($files); /* Sort descending */
		return $files;
	}

	function format_day($text) {
		$text = trim(ltrim($text,"\n"),"\n");
		$text = ereg_replace("^([0-9]{2}:[0-9]{2})\n","<b><small>\\1</small></b>\n<p>",$text);
		$text = ereg_replace("\n([0-9]{2}:[0-9]{2})\n","</p>\n<b><small>\\1</small></b>\n<p>",$text);
		$text = ereg_replace("\n\n","</p>\n<p>",$text);
		if (!ereg("^<", $text))
			$text = "<p>" . $text;
		return $text;
	}

	function show_comment($text, $author, $email, $url, $published, $last_comment=false) {
		while (ereg("[^[:space:]]{50,}",$text)) {
			$text = ereg_replace("([^[:space:]]{49})","\\1 ",$text);
		}
		while (ereg("[:space:]{10,}",$text)) {
			$text = ereg_replace("[:space:]{10,}"," ",$text);
		}
		while (ereg("\n{4,}",$text)) {
			$text = ereg_replace("\n{4,}","\n",$text);
		}
		$text = ereg_replace("\\ n",'n',$text);

		print "<p>".nl2br(htmlspecialchars($text))."</p>\n";
		if (!$last_comment) {
			print "<p class=\"author\">";
		} else {
			print "<p>";
		}
		print "  <b>".htmlspecialchars($author)."</b> ";
		if (strlen($email)) {
			$email = ereg_replace("@", "_AT_",$email);
			print " (<a href=\"mailto:" . urlencode($email) . "\">email</a>)";
		}
		if (strlen($url)) {
			$url = ereg_replace('"',"",$url);
			print " (<a href=\"http://" . ereg_replace("^http://","",$url) . "\">www</a>)";
		}
		print "  <b>".date("d-M-Y H:i", $published)."</b></p>\n";
	}

	function print_comments($date) {
		$comments = array();
		$total_comments = 0;
		$comment_file = COMMENT_DIR . $date . ".comments.txt";

		if (file_exists($comment_file) && is_readable($comment_file)) {
			$writable = is_writable($comment_file);
			$tmp = file($comment_file);
			$total_comments = count($tmp);
			print "<span class=\"cmtlinks\">[ : <b>{$total_comments}</b> / <a href=\"" . BASEDIR . "addcomment.php/{$date}#add\"> </a> ]</span>\n";
			if ($total_comments) {
				print "<blockquote id=\"cmt{$date}\">\n<h5></h5>\n";
				$cnt = 0;
				foreach($tmp as $id => $line) {
					@list($published, $ip, $proxy, $ua, $author, $email, $url, $text) = split("\t", $line);
					if ((int)$published > 0) {
						if ($cnt+1 == $total_comments) {
							print "<a name=\"lastcomment\"></a>\n";
						}
						$text = ereg_replace("\\\\n","\n",$text);
						$cnt++;
						show_comment($text, $author, $email, $url, $published, $cnt == $total_comments);
						if ($cnt < $total_comments) {
							print "<hr noshade>\n";
						}
					}
				}
				print "<br>\n</blockquote>\n";
			}
		} else {
			print "<span class=\"cmtlinks\">[ <a href=\"" . BASEDIR . "addcomment.php/{$date}#add\"> </a> ]</span>\n";
		}
	}

	function print_day($date, $text) {
		$text = format_day($text);
?>
<a name="<?=$date?>"></a>
<h5><a href="<?=BASEDIR?>archive.php/<?=$date?>"><?=date("D, d M Y",strtotime($date))?></a></h5>
<?=$text?></p>
<?
		print_comments($date);
	}

	function load_adventures() {
		$adventures = array();
		$filename = get_filename("adventures");
		if (file_exists($filename)) {
			$adv = file($filename);
			foreach ($adv as $i => $text) {
				list($name,$title,$alldates) = split(";", $text);
				$dates = array(); $dates = split(" ",trim(ltrim($alldates)));
				$adventures[$name]["title"] = $title;
				$adventures[$name]["dates"] = $dates;
			}
		}
		return $adventures;
	}

	function html_begin($title="", $diary_link=true) {
		if ($title == "")
			$title = BLOG_TITLE;
		else
			$title = BLOG_TITLE . " / " . $title;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
	<meta http-equiv="content-type" content="text/html; charset=windows-1251" />
	<meta name="author" content="<?=AUTHOR_NAME?>" />
	<meta name="generator" content="gf's blog" />
	<link href="<?=BASEDIR?>diary.css" rel="stylesheet" type="text/css" />
	<link rel="SHORTCUT ICON" href="<?=BASEDIR?>favicon.png" />
	<title><?=$title?></title>
</head>
<body>
<a name="top"></a>

<a href="/">&lt; HomePage</a>
<div id="spacer">
<?		if ($diary_link) { ?>
<a href="<?=BASEDIR?>">&lt;- </a><br />
<?		}
	}

	function html_end() {
?>
</div>

<div align="right">
<a href="http://validator.w3.org/check/referer"><img border="0" src="/valid-xhtml10.png" alt="Valid XHTML 1.0!" height="31" width="88" /></a>
<a href="http://jigsaw.w3.org/css-validator/validator?uri=http://georgi.unixsol.org/site.css"><img border="0" style="border:0;width:88px;height:31px" src="/vcss.png" alt="Valid CSS!" /></a>

<!-- Creative Commons License -->
<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/1.0/"><img alt="Creative Commons License" border="0" src="<?=BASEDIR?>somerights.gif" /></a>
<!-- /Creative Commons License -->

<!--

<rdf:RDF xmlns="http://web.resource.org/cc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
<Work rdf:about="">
   <dc:type rdf:resource="http://purl.org/dc/dcmitype/Text" />
   <license rdf:resource="http://creativecommons.org/licenses/by-nc-sa/1.0/" />
</Work>

<License rdf:about="http://creativecommons.org/licenses/by-nc-sa/1.0/">
   <permits rdf:resource="http://web.resource.org/cc/Reproduction" />
   <permits rdf:resource="http://web.resource.org/cc/Distribution" />
   <requires rdf:resource="http://web.resource.org/cc/Notice" />
   <requires rdf:resource="http://web.resource.org/cc/Attribution" />
   <prohibits rdf:resource="http://web.resource.org/cc/CommercialUse" />
   <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
   <requires rdf:resource="http://web.resource.org/cc/ShareAlike" />
</License>

</rdf:RDF>

-->

</div>

</body>
</html>
<?
	}
?>

==> glog-2.00.tar.gz: glog-2.00/funcs.php <==
<?php
# Library functions
#
# $Id: funcs.php,v 1.10 2004/06/08 21:41:29 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (PROGRAM != 1)
		exit;

	include("config.php");

	function get_filename($fname) {
		return DAY_DIR . $fname . ".txt";
	}

	/* !!! Global !!! Needs further optimizations !!! */
	$days = load_days();
	$months = array();
	foreach ($days as $tmp => $tmpdate) {
		$tmpdate = ereg_replace("-[0-9]+$","",$tmpdate);
		if (!isset($months[$tmpdate])) {
			$months[$tmpdate] = $tmpdate;
		}
	}
	asort($months);
	$months_txt = array(
		1	=>	"",
		2	=>	"",
		3	=>	"",
		4	=>	"",
		5	=>	"",
		6	=>	"",
		7	=>	"",
		8	=>	"",
		9	=>	"",
		10	=>	"",
		11	=>	"",
		12	=>	""
	);

	$days_txt = array(
		0	=>	"",
		1	=>	"",
		2	=>	"",
		3	=>	"",
		4	=>	"",
		5	=>	"",
		6	=>	""
	);

	/*      $length */
	function gen_uniq($rnd=0,$length=12) {
		srand((double)microtime()*10000000+$rnd);
		$Pool = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz01234567890';
		$sid = '';
		for($index = 0; $index < $length; $index++) {
			$sid .= substr($Pool, (rand()%(strlen($Pool))), 1);
		}
		return($sid);
	}

	function load_days() {
		$files = array();
		if (is_dir(DAY_DIR) && is_readable(DAY_DIR)) {
			if ($dh = opendir(DAY_DIR)) {
				while (($file = readdir($dh)) !== false) {
					if (filetype(DAY_DIR . $file) == "file" &&
					    ereg("[0-9]{4}-[0-9]{2}-[0-9]{2}\.txt$", $file))
					{
						$file = ereg_replace(".txt$","",$file);
						$files[$file] = $file;
					}
				}
				closedir($dh);
			}
		} else {
			print "Can't open \"" . DAY_DIR . "\" directory.<br />Make sure the directory exists and has correct permissions!<br /><br />";
		}
		arsort($files); /* Sort descending */
		return $files;
	}

	function format_day($text) {
		$text = trim(ltrim($text,"\n"),"\n");
		$text = ereg_replace("^([0-9]{2}:[0-9]{2})\n","<b><small>\\1</small></b>\n<p>",$text);
		$text = ereg_replace("\n([0-9]{2}:[0-9]{2})\n","</p>\n<b><small>\\1</small></b>\n<p>",$text);
		$text = ereg_replace("\n\n","</p>\n<p>",$text);
		if (!ereg("^<", $text))
			$text = "<p>" . $text;
		return $text;
	}

	function show_comment($text, $author, $email, $url, $published, $last_comment=false) {
		while (ereg("[^[:space:]]{50,}",$text)) {
			$text = ereg_replace("([^[:space:]]{49})","\\1 ",$text);
		}
		while (ereg("[:space:]{10,}",$text)) {
			$text = ereg_replace("[:space:]{10,}"," ",$text);
		}
		while (ereg("\n{4,}",$text)) {
			$text = ereg_replace("\n{4,}","\n",$text);
		}
		$text = ereg_replace("\\ n",'n',$text);

		print "<p>".nl2br(htmlspecialchars($text))."</p>\n";
		if (!$last_comment) {
			print "<p class=\"author\">";
		} else {
			print "<p>";
		}
		print "  <b>".htmlspecialchars($author)."</b> ";
		if (strlen($email)) {
			$email = ereg_replace("@", "_AT_",$email);
			print " (<a href=\"mailto:" . urlencode($email) . "\">email</a>)";
		}
		if (strlen($url)) {
			$url = ereg_replace('"',"",$url);
			print " (<a href=\"http://" . ereg_replace("^http://","",$url) . "\">www</a>)";
		}
		print "  <b>".date("d-M-Y H:i", $published)."</b></p>\n";
	}

	function print_comments($date) {
		$comments = array();
		$total_comments = 0;
		$comment_file = COMMENT_DIR . $date . ".comments.txt";

		if (file_exists($comment_file) && is_readable($comment_file)) {
			$writable = is_writable($comment_file);
			$tmp = file($comment_file);
			$total_comments = count($tmp);
//			print "<span class=\"cmtlinks\">[ : <b>{$total_comments}</b> / <a href=\"" . BASEDIR . "addcomment.php/{$date}#add\"> </a> ]</span>\n";
			print "<span class=\"cmtlinks\">[ : <b>{$total_comments}</b> / <a href=\"http://georgi.unixsol.org/diary/addcomment.php/{$date}#add\"> </a> ]</span>\n";
			if ($total_comments) {
				print "<blockquote id=\"cmt{$date}\">\n<h5></h5>\n";
				$cnt = 0;
				foreach($tmp as $id => $line) {
					@list($published, $ip, $proxy, $ua, $author, $email, $url, $text) = split("\t", $line);
					if ((int)$published > 0) {
						if ($cnt+1 == $total_comments) {
							print "<a name=\"lastcomment\"></a>\n";
						}
						$text = ereg_replace("\\\\n","\n",$text);
						$cnt++;
						show_comment($text, $author, $email, $url, $published, $cnt == $total_comments);
						if ($cnt < $total_comments) {
							print "<hr noshade = \"noshade\" />\n";
						}
					}
				}
				print "<br />\n</blockquote>\n";
			}
		} else {
//			print "<span class=\"cmtlinks\">[ <a href=\"" . BASEDIR . "addcomment.php/{$date}#add\"> </a> ]</span>\n";
			print "<span class=\"cmtlinks\">[ <a href=\"http://georgi.unixsol.org/diary/addcomment.php/{$date}#add\"> </a> ]</span>\n";
		}
	}

	function print_day($date, $text) {
		global $days_txt, $months_txt;
		$text = format_day($text);
?>
<a name="<?=$date?>"></a>
<h5><a href="<?=BASEDIR?>archive.php/<?=$date?>"><?
	$dt = strtotime($date);
	print $days_txt[date("w", $dt)];
	print ereg_replace(" 0"," ",date(", d ",$dt));
	print $months_txt[(int)date("m",$dt)];
	print date(" Y",$dt);
?></a></h5>
<?=$text?></p>
<?
		print_comments($date);
	}

	function load_adventures() {
		$adventures = array();
		$filename = get_filename("adventures");
		if (file_exists($filename)) {
			$adv = file($filename);
			foreach ($adv as $i => $text) {
				list($name,$title,$alldates) = split(";", $text);
				$dates = array(); $dates = split(" ",trim(ltrim($alldates)));
				$adventures[$name]["title"] = $title;
				$adventures[$name]["dates"] = $dates;
			}
		}
		return $adventures;
	}

	function html_begin($title="", $diary_link=true) {
		if ($title == "")
			$title = BLOG_TITLE;
		else
			$title = BLOG_TITLE . " / " . $title;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
	<meta http-equiv="content-type" content="text/html; charset=windows-1251" />
	<meta name="author" content="<?=AUTHOR_NAME?>" />
	<meta name="generator" content="gf's blog" />
	<link href="<?=BASEDIR?>diary.css" rel="stylesheet" type="text/css" />
	<link rel="alternate stylesheet" title="Black" href="<?=BASEDIR?>diary_black.css" />
	<link rel="alternate stylesheet" title="Blue" href="<?=BASEDIR?>diary_blue.css" />
	<link rel="alternate stylesheet" title="Orange" href="<?=BASEDIR?>diary_orange.css" />
	<link rel="SHORTCUT ICON" href="<?=BASEDIR?>favicon.png" />
	<title><?=$title?></title>
</head>
<body>
<a name="top"></a>

<a href="/">&lt; HomePage</a>
<div id="spacer">
<?		if ($diary_link) { ?>
<a href="<?=BASEDIR?>">&lt;- </a><br />
<?		}
	}

	function html_end() {
?>
</div>

<div align="right">
<a href="http://validator.w3.org/check/referer"><img border="0" src="<?=BASEDIR?>images/valid-xhtml10.png" alt="Valid XHTML 1.0!" height="31" width="88" title="Validate my HTML" /></a>
<a href="http://jigsaw.w3.org/css-validator/validator?uri=http://<?=$_SERVER['SERVER_NAME']?><?=BASEDIR?>diary.css"><img border="0" width="88" height="31" style="border:0;width:88px;height:31px" src="<?=BASEDIR?>images/vcss.png" alt="Valid CSS!" title="Validate my CSS" /></a>
<a href="http://feeds.archive.org/validator/check.cgi?url=http://<?=$_SERVER['SERVER_NAME']?><?=BASEDIR?>index.xml.php"><img border="0" src="<?=BASEDIR?>images/valid-rss.png" alt="[Valid RSS]" title="Validate my RSS feed" width="88" height="31" /></a>

<!-- Creative Commons License -->
<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/1.0/"><img alt="Creative Commons License" border="0" src="<?=BASEDIR?>images/somerights.gif" width="88" height="31" title="Read more about Creative Commons" /></a>
<!-- /Creative Commons License -->

<!--

<rdf:RDF xmlns="http://web.resource.org/cc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
<Work rdf:about="">
   <dc:type rdf:resource="http://purl.org/dc/dcmitype/Text" />
   <license rdf:resource="http://creativecommons.org/licenses/by-nc-sa/1.0/" />
</Work>

<License rdf:about="http://creativecommons.org/licenses/by-nc-sa/1.0/">
   <permits rdf:resource="http://web.resource.org/cc/Reproduction" />
   <permits rdf:resource="http://web.resource.org/cc/Distribution" />
   <requires rdf:resource="http://web.resource.org/cc/Notice" />
   <requires rdf:resource="http://web.resource.org/cc/Attribution" />
   <prohibits rdf:resource="http://web.resource.org/cc/CommercialUse" />
   <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
   <requires rdf:resource="http://web.resource.org/cc/ShareAlike" />
</License>

</rdf:RDF>

-->

</div>

</body>
</html>
<?
	}
?>
